;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "migemo" "20250616.309"
  "Japanese incremental search through dynamic pattern expansion."
  '((emacs "25"))
  :url "https://github.com/emacs-jp/migemo"
  :commit "c0d84b4092ddade01110ba875559bfd454862ac2"
  :revdesc "c0d84b4092dd"
  :authors '(("Satoru Takabayashi" . "satoru-t@is.aist-nara.ac.jp"))
  :maintainers '(("Satoru Takabayashi" . "satoru-t@is.aist-nara.ac.jp")))
